"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const node_fetch_1 = require("node-fetch");
class GitHub {
    constructor(oauthToken) {
        this.oauthTokenField = oauthToken;
    }
    get oauthToken() {
        return this.oauthTokenField;
    }
    getComments(owner, repository, issueNumber) {
        const commentsUrl = this.getCommentsUrl(owner, repository, issueNumber);
        return this.callFetch(commentsUrl, {
            headers: this.getHeaders(),
            method: "GET",
        }).then(this.handleResponse);
    }
    deleteComment(owner, repository, commentId) {
        const commentsUrl = this.getCommentsUrl(owner, repository);
        return this.callFetch(`${commentsUrl}/${commentId}`, {
            headers: this.getHeaders(),
            method: "DELETE"
        });
    }
    postComment(owner, repository, issueNumber, body) {
        const commentsUrl = this.getCommentsUrl(owner, repository, issueNumber);
        return this.callFetch(commentsUrl, {
            body: JSON.stringify({ body }),
            headers: this.getHeaders(),
            method: "POST",
        }).then(this.handleResponse);
    }
    getRepoUrl(owner, repository) {
        return `https://api.github.com/repos/${owner}/${repository}`;
    }
    getIssuesUrl(owner, repository, issueNumber) {
        let url = this.getRepoUrl(owner, repository);
        url += "/issues";
        if (undefined === issueNumber) {
            return url;
        }
        return `${url}/${issueNumber}`;
    }
    getCommentsUrl(owner, repository, issueNumber) {
        return this.getIssuesUrl(owner, repository, issueNumber) + "/comments";
    }
    getHeaders() {
        const headers = {
            "Content-Type": "application/json",
        };
        if (undefined !== this.oauthToken) {
            headers.Authorization = `token ${this.oauthToken}`;
        }
        return headers;
    }
    handleResponse(response) {
        if (response.ok) {
            return response.json();
        }
        throw new Error(`fetch: response.ok is false.`);
    }
    callFetch(url, options) {
        return node_fetch_1.default(url, options);
    }
}
exports.GitHub = GitHub;
//# sourceMappingURL=GitHub.js.map